# Security Policy

## Supported Versions

Only the latest release is supported with security updates.

| Version | Supported |
|---------|-----------|
| Latest  | Yes       |
| Older   | No        |

## Reporting a Vulnerability

**Please do not open a public issue for security vulnerabilities.**

Instead, use one of these methods:

1. **GitHub Private Vulnerability Reporting** — use the "Report a vulnerability" button on the
   [Security tab](https://github.com/tobocop2/lilbee/security/advisories/new)
2. **Email** — contact [@tobocop2](https://github.com/tobocop2) directly

### What to expect

- Acknowledgment within 72 hours
- Status update within 1 week
- We will coordinate disclosure timing with you
